import React, { useCallback, useEffect, useRef, useState } from 'react';
import { Dimensions } from 'react-native';
import styled from 'styled-components/native';
import LinearGradient from 'react-native-linear-gradient';
import palette from '../static/palette';

export interface GetchaModalProps {
  modalTitle?: string;
  buttonTitle?: string;
  children?: React.FC | JSX.Element;
  onPressButton: () => void;
}

const ModalBackground = styled.View`
  justify-content: center;
  align-items: center;
  width: ${Dimensions.get('window').width};
  height: ${Dimensions.get('window').height};
  background-color: rgba(0, 0, 0, 0.5);
`;

const ModalBlock = styled.View`
  width: 288px;
  height: auto;
  min-height: 148px;
  max-height: 492px;
  border-radius: 4px;
  background-color: ${palette.base.white};
  position: relative;
  overflow: hidden;
`;

const ModalTitle = styled.Text`
  width: inherit;
  height: 58px;
  padding: 18px 20px;

  font-weight: bold;
  font-size: 16px;
  line-height: 22px;
  letter-spacing: -0.5px;
`;

const ModalScrollBody = styled.ScrollView`
  width: inherit;
  height: auto;
  position: relative;
`;

interface GradientProps {
  isShow?: boolean;
}

const StyledGradientTop = styled(LinearGradient)<GradientProps>`
  opacity: ${(props) => (props.isShow ? 1 : 0)};
  width: 100%;
  height: 24px;
  position: absolute;
  top: 58px;
  left: 0px;
  z-index: 1001;
  transition: all 500ms ease-in-out;
`;

const StyledGradientBottom = styled(LinearGradient)<GradientProps>`
  opacity: ${(props) => (props.isShow ? 1 : 0)};
  width: 100%;
  height: 24px;
  position: absolute;
  bottom: 42px;
  left: 0px;
  z-index: 1001;
  transition: all 500ms ease-in-out;
`;

const ModalScrollBodyView = styled.View`
  width: inherit;
  height: inherit;
  box-sizing: border-box;
  padding-left: 20px;
  padding-bottom: 42px;
`;

const ModalButton = styled.TouchableOpacity`
  position: absolute;
  justify-content: center;
  align-items: center;
  width: inherit;
  height: 42px;
  bottom: 0;
  left: 0;
  background-color: ${palette.point.red_getcha};
`;

const ModalButtonText = styled.Text`
  color: ${palette.base.white};
  font-weight: bold;
  font-size: 12px;
  line-height: 12px;
  text-align: center;
  letter-spacing: -0.5px;
`;

const GetchaModal: React.FC<GetchaModalProps> = ({
  modalTitle = '팝업 타이틀',
  buttonTitle = '버튼 타이틀',
  children,
  onPressButton = () => {},
}) => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const blockRef: any = useRef(null);
  const [isMaxSize, setIsMaxSize] = useState<boolean>(false);
  const [onScroll, setOnScroll] = useState<boolean>(false);

  useEffect(() => {
    if (blockRef.current?.clientHeight >= 492) {
      setIsMaxSize(true);
    } else setIsMaxSize(false);
  }, [isMaxSize]);

  const listenScrollEvent = useCallback(() => {
    if (onScroll) return;
    setOnScroll(true);
    setTimeout(() => {
      setOnScroll(false);
    }, 1000);
  }, [onScroll]);

  return (
    <ModalBackground>
      <ModalBlock ref={blockRef}>
        <ModalTitle>{modalTitle}</ModalTitle>
        <StyledGradientTop
          colors={['#ffffff', 'rgba(255,255,255,0.0001)']}
          start={{ x: 0, y: 0 }}
          end={{ x: 0, y: 0.7 }}
          isShow={isMaxSize && onScroll}
        />
        <ModalScrollBody
          showsVerticalScrollIndicator={false}
          onScroll={listenScrollEvent}
          scrollEventThrottle={16}
        >
          <ModalScrollBodyView>{children}</ModalScrollBodyView>
        </ModalScrollBody>
        <ModalButton onPress={onPressButton}>
          <ModalButtonText>{buttonTitle}</ModalButtonText>
        </ModalButton>
        <StyledGradientBottom
          colors={['rgba(255,255,255,0.0001)', '#ffffff']}
          start={{ x: 0, y: 0 }}
          end={{ x: 0, y: 0.7 }}
          isShow={isMaxSize && onScroll}
        />
      </ModalBlock>
    </ModalBackground>
  );
};

export default GetchaModal;
